=======
Credits
=======

Development Lead
----------------

* `Joachim Jablon / @ewjoachim <https://github.com/ewjoachim>`_ <joachim.jablon /at/ people-doc.com>

Contributors (by alphabetic order)
----------------------------------

- `@brunobord <https://github.com/brunobord>`_
- `@k4nar <https://github.com/k4nar>`_
- `@zebuline <https://github.com/zebuline>`_
